@@ -36,16 +36,3 @@ run_app <- function(...) {
     golem_opts = list(...)
   )
 }
-
-#' ReviewR: A light-weight, portable tool for reviewing individual patient records
-#'
-#' ReviewR is a portable Shiny tool to help you explore data across different 
-#' data models. Within ReviewR, you can browse patient data stored in either 
-#' the OMOP or MIMIC-III data model. In addition to viewing patient data, you 
-#' may also connect to a REDCap project to perform a chart review.
-#' 
-#'
-#' @docType package
-#' @name ReviewR
-NULL
-#> NULL
